@@ -52,7 +52,7 @@ import java.util.Date;
 
 public class RssResult {
 	private String url, author, format, body, subject, feedUrl, feedTitle, imageUrl;
-	private Date publishedDate;
+	private Date date;
 
 	public String getUrl() {
 		return url;
@@ -85,9 +85,9 @@ public class RssResult {
 	public String getImageUrl() {
 		return this.imageUrl;
 	}
-	
+
 	public Date getDate() {
-		return this.publishedDate;
+		return this.date;
 	}
 
 	public RssResult setUrl(String url) {
@@ -114,24 +114,29 @@ public class RssResult {
 		this.subject = subject;
 		return this;
 	}
-	
+
 	public RssResult setFeedUrl(String feedUrl) {
 		this.feedUrl = feedUrl;
 		return this;
 	}
-	
+
 	public RssResult setFeedTitle(String feedTitle) {
 		this.feedTitle = feedTitle;
 		return this;
 	}
-	
+
 	public RssResult setImageUrl(String imageUrl) {
 		this.imageUrl = imageUrl;
 		return this;
 	}
 
-	public RssResult setDate(Date publishedDate) {
-		this.publishedDate = publishedDate;
+	public RssResult setDate(Date... possibleDates) {
+		for(Date d: possibleDates) {
+			if(d != null) {
+				this.date = d;
+				return this;
+			}
+		}
 		return this;
 	}
 }
