@@ -49,6 +49,8 @@
 
 package com.openexchange.rss.osgi;
 
+import java.util.Dictionary;
+import java.util.Hashtable;
 import com.openexchange.ajax.requesthandler.ResultConverter;
 import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
 import com.openexchange.capabilities.CapabilityChecker;
@@ -60,7 +62,9 @@ import com.openexchange.html.HtmlService;
 import com.openexchange.rss.RssJsonConverter;
 import com.openexchange.rss.RssServices;
 import com.openexchange.rss.actions.RssActionFactory;
+import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tools.session.ServerSessionAdapter;
 
 public class RssActivator extends AJAXModuleActivator {
 
@@ -74,11 +78,15 @@ public class RssActivator extends AJAXModuleActivator {
         RssServices.LOOKUP.set(this);
         registerModule(new RssActionFactory(), "rss");
         registerService(ResultConverter.class, new RssJsonConverter());
+
+        final Dictionary<String, Object> properties = new Hashtable<String, Object>(1);
+        properties.put(CapabilityChecker.PROPERTY_CAPABILITIES, "rss");
         registerService(CapabilityChecker.class, new CapabilityChecker() {
 
             @Override
-            public boolean isEnabled(String capability, ServerSession session) throws OXException {
+            public boolean isEnabled(String capability, Session ses) throws OXException {
                 if ("rss".equals(capability)) {
+                    final ServerSession session = ServerSessionAdapter.valueOf(ses);
                     if (session.isAnonymous()) {
                         return false;
                     }
@@ -91,7 +99,8 @@ public class RssActivator extends AJAXModuleActivator {
                 return true;
 
             }
-        });
+        }, properties);
+
         getService(CapabilityService.class).declareCapability("rss");
     }
 
